@@ -56,14 +56,17 @@ KEY_TYPE_CAP=${class:0:$keylen}
 VALUE_TYPE_CAP=Object # Just for filling holes
 
 if [[ "${rem:0:1}" == "2" ]]; then
-    isFunction=true
     rem=${rem:1}
     rem2=${rem##[A-Z]+([a-z])}
     valuelen=$(( ${#rem} - ${#rem2} ))
     VALUE_TYPE_CAP=${rem:0:$valuelen}
     root=$rem2
-else
-    isFunction=false
+fi
+
+if [[ "$class" == *Pair ]]; then
+    rem2=${rem##[A-Z]+([a-z])}
+    valuelen=$(( ${#rem} - ${#rem2} ))
+    VALUE_TYPE_CAP=${rem:0:$valuelen}
 fi
 
 for((k=0; k<${#TYPE_CAP[*]}; k++)); do
@@ -198,11 +201,15 @@ fi)\
 \
 \
 "#define KEY_TYPE ${TYPE[$k]}\n"\
+"#define KEY_TYPE_CAP ${TYPE_CAP[$k]}\n"\
 "#define VALUE_TYPE ${TYPE[$v]}\n"\
+"#define VALUE_TYPE_CAP ${TYPE_CAP[$v]}\n"\
+"#define KEY_INDEX $k\n"\
 "#define KEY_TYPE_WIDENED ${TYPE[$wk]}\n"\
 "#define VALUE_TYPE_WIDENED ${TYPE[$wv]}\n"\
 "#define KEY_CLASS ${CLASS[$k]}\n"\
 "#define VALUE_CLASS ${CLASS[$v]}\n"\
+"#define VALUE_INDEX $v\n"\
 "#define KEY_CLASS_WIDENED ${CLASS[$wk]}\n"\
 "#define VALUE_CLASS_WIDENED ${CLASS[$wv]}\n"\
 \
@@ -221,6 +228,8 @@ fi)\
 "#define KEY_GENERIC_CAST (K)\n"\
 "#define KEY_GENERIC_ARRAY_CAST (K[])\n"\
 "#define KEY_GENERIC_BIG_ARRAY_CAST (K[][])\n"\
+"#define DEPRECATED_IF_KEYS_REFERENCE @Deprecated\n"\
+"#define DEPRECATED_IF_KEYS_PRIMITIVE\n"\
 "#define SUPPRESS_WARNINGS_KEY_UNCHECKED @SuppressWarnings(\"unchecked\")\n"\
 "#define SUPPRESS_WARNINGS_KEY_RAWTYPES @SuppressWarnings(\"rawtypes\")\n"\
 "#define SUPPRESS_WARNINGS_KEY_UNCHECKED_RAWTYPES @SuppressWarnings({\"unchecked\",\"rawtypes\"})\n"\
@@ -243,6 +252,8 @@ fi)\
 "#define KEY_GENERIC_CAST\n"\
 "#define KEY_GENERIC_ARRAY_CAST\n"\
 "#define KEY_GENERIC_BIG_ARRAY_CAST\n"\
+"#define DEPRECATED_IF_KEYS_REFERENCE\n"\
+"#define DEPRECATED_IF_KEYS_PRIMITIVE @Deprecated\n"\
 "#define SUPPRESS_WARNINGS_KEY_UNCHECKED\n"\
 "#define SUPPRESS_WARNINGS_KEY_RAWTYPES\n"\
 "#define SUPPRESS_WARNINGS_KEY_UNCHECKED_RAWTYPES\n"\
@@ -260,6 +271,8 @@ fi)\
 "#define VALUE_SUPER_GENERIC <? super V>\n"\
 "#define VALUE_GENERIC_CAST (V)\n"\
 "#define VALUE_GENERIC_ARRAY_CAST (V[])\n"\
+"#define DEPRECATED_IF_VALUES_REFERENCE @Deprecated\n"\
+"#define DEPRECATED_IF_VALUES_PRIMITIVE\n"\
 "#define SUPPRESS_WARNINGS_VALUE_UNCHECKED @SuppressWarnings(\"unchecked\")\n"\
 "#define SUPPRESS_WARNINGS_VALUE_RAWTYPES @SuppressWarnings(\"rawtypes\")\n"\
 "#else\n"\
@@ -273,6 +286,8 @@ fi)\
 "#define VALUE_SUPER_GENERIC\n"\
 "#define VALUE_GENERIC_CAST\n"\
 "#define VALUE_GENERIC_ARRAY_CAST\n"\
+"#define DEPRECATED_IF_VALUES_REFERENCE\n"\
+"#define DEPRECATED_IF_VALUES_PRIMITIVE @Deprecated\n"\
 "#define SUPPRESS_WARNINGS_VALUE_UNCHECKED\n"\
 "#define SUPPRESS_WARNINGS_VALUE_RAWTYPES\n"\
 "#endif\n"\
@@ -328,6 +343,16 @@ fi)\
 "#define FUNCTION ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Function\n"\
 "#define MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Map\n"\
 "#define SORTED_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}SortedMap\n"\
+"#if KEY_CLASS_Object && VALUE_CLASS_Object\n"\
+"#define PAIR it.unimi.dsi.fastutil.Pair\n"\
+"#define SORTED_PAIR it.unimi.dsi.fastutil.SortedPair\n"\
+"#else\n"\
+"#define PAIR ${TYPE_CAP[$k]}${TYPE_CAP[$v]}Pair\n"\
+"#define SORTED_PAIR ${TYPE_CAP[$k]}${TYPE_CAP[$v]}SortedPair\n"\
+"#endif\n"\
+"#define MUTABLE_PAIR ${TYPE_CAP[$k]}${TYPE_CAP[$v]}MutablePair\n"\
+"#define IMMUTABLE_PAIR ${TYPE_CAP[$k]}${TYPE_CAP[$v]}ImmutablePair\n"\
+"#define IMMUTABLE_SORTED_PAIR ${TYPE_CAP[$k]}${TYPE_CAP[$k]}ImmutableSortedPair\n"\
 "#if KEYS_REFERENCE\n"\
 "#define STD_SORTED_MAP SortedMap\n"\
 "#define STRATEGY Strategy\n"\
@@ -338,6 +363,7 @@ fi)\
 "#define LIST ${TYPE_CAP[$k]}List\n"\
 "#define BIG_LIST ${TYPE_CAP[$k]}BigList\n"\
 "#define STACK ${TYPE_STD[$k]}Stack\n"\
+"#define ATOMIC_ARRAY Atomic${CLASS[$k]}Array\n"\
 "#define PRIORITY_QUEUE ${TYPE_STD[$k]}PriorityQueue\n"\
 "#define INDIRECT_PRIORITY_QUEUE ${TYPE_STD[$k]}IndirectPriorityQueue\n"\
 "#define INDIRECT_DOUBLE_PRIORITY_QUEUE ${TYPE_STD[$k]}IndirectDoublePriorityQueue\n"\
@@ -349,6 +375,7 @@ fi)\
 "#define KEY_LIST_ITERATOR ${TYPE_CAP2[$k]}ListIterator\n"\
 "#define KEY_BIG_LIST_ITERATOR ${TYPE_CAP2[$k]}BigListIterator\n"\
 "#define STD_KEY_ITERATOR ${TYPE_STD[$k]}Iterator\n"\
+"#define STD_KEY_ITERABLE ${TYPE_STD[$k]}Iterable\n"\
 "#define KEY_COMPARATOR ${TYPE_STD[$k]}Comparator\n"\
 \
 \
@@ -414,6 +441,7 @@ fi)\
 "#define ARRAYS ${TYPE_CAP2[$k]}Arrays\n"\
 "#define BIG_ARRAYS ${TYPE_CAP2[$k]}BigArrays\n"\
 "#define ITERATORS ${TYPE_CAP2[$k]}Iterators\n"\
+"#define ITERABLES ${TYPE_CAP2[$k]}Iterables\n"\
 "#define BIG_LIST_ITERATORS ${TYPE_CAP2[$k]}BigListIterators\n"\
 "#define COMPARATORS ${TYPE_CAP2[$k]}Comparators\n"\
 \
@@ -446,6 +474,7 @@ fi)\
 "#define ARRAY_LIST ${TYPE_CAP[$k]}ArrayList\n"\
 "#define BIG_ARRAY_BIG_LIST ${TYPE_CAP[$k]}BigArrayBigList\n"\
 "#define ARRAY_FRONT_CODED_LIST ${TYPE_CAP[$k]}ArrayFrontCodedList\n"\
+"#define ARRAY_FRONT_CODED_BIG_LIST ${TYPE_CAP[$k]}ArrayFrontCodedBigList\n"\
 "#define HEAP_PRIORITY_QUEUE ${TYPE_CAP2[$k]}HeapPriorityQueue\n"\
 "#define HEAP_SEMI_INDIRECT_PRIORITY_QUEUE ${TYPE_CAP2[$k]}HeapSemiIndirectPriorityQueue\n"\
 "#define HEAP_INDIRECT_PRIORITY_QUEUE ${TYPE_CAP2[$k]}HeapIndirectPriorityQueue\n"\
@@ -499,6 +528,9 @@ fi)\
 "#define FIRST_KEY first${TYPE_STD[$k]}Key\n"\
 "#define LAST_KEY last${TYPE_STD[$k]}Key\n"\
 "#define GET_KEY get${TYPE_STD[$k]}\n"\
+"#define PAIR_LEFT left${TYPE_STD[$k]}\n"\
+"#define PAIR_FIRST first${TYPE_STD[$k]}\n"\
+"#define PAIR_KEY key${TYPE_STD[$k]}\n"\
 "#define REMOVE_KEY remove${TYPE_STD[$k]}\n"\
 "#define READ_KEY read${TYPE_CAP2[$k]}\n"\
 "#define WRITE_KEY write${TYPE_CAP2[$k]}\n"\
@@ -534,6 +566,9 @@ fi)\
 "#define ENTRY_GET_VALUE get${TYPE_STD[$v]}Value\n"\
 "#define REMOVE_FIRST_VALUE removeFirst${TYPE_STD[$v]}\n"\
 "#define REMOVE_LAST_VALUE removeLast${TYPE_STD[$v]}\n"\
+"#define PAIR_RIGHT right${TYPE_STD[$v]}\n"\
+"#define PAIR_SECOND second${TYPE_STD[$v]}\n"\
+"#define PAIR_VALUE value${TYPE_STD[$v]}\n"\
 \
 \
 "/* Methods (keys/values) */\n"\
