@@ -1,7 +1,7 @@
 package it.unimi.dsi.fastutil.chars;
 
 /*
- * Copyright (C) 2017 Sebastiano Vigna
+ * Copyright (C) 2017-2020 Sebastiano Vigna
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -101,7 +101,7 @@ public class CharArrayFrontCodedListTest {
 				}
 			}
 		}
-		java.io.File ff = new java.io.File("it.unimi.dsi.fastutil.test");
+		java.io.File ff = new java.io.File("it.unimi.dsi.fastutil.test.junit." + m.getClass().getSimpleName() + "." + n);
 		java.io.OutputStream os = new java.io.FileOutputStream(ff);
 		java.io.ObjectOutputStream oos = new java.io.ObjectOutputStream(os);
 		oos.writeObject(m);
