@@ -50,6 +50,26 @@ public class IntArrayListTest {
 		assertEquals(IntArrayList.wrap(new int[] { 42, 24 }), list);
 	}
 
+	@Test
+	public void testAddAll() {
+		final IntArrayList l = IntArrayList.wrap(new int[] { 0, 1 });
+		l.addAll(IntArrayList.wrap(new int[] { 2, 3 } ));
+		assertEquals(IntArrayList.wrap(new int[] { 0, 1, 2, 3 }), l);
+		// Test object based lists still work too.
+		l.addAll(java.util.Arrays.asList(Integer.valueOf(4), Integer.valueOf(5)));
+		assertEquals(IntArrayList.wrap(new int[] { 0, 1, 2, 3, 4, 5 }), l);
+	}
+
+	@Test
+	public void testAddAllAtIndex() {
+		final IntArrayList l = IntArrayList.wrap(new int[] { 0, 3 });
+		l.addAll(1, IntArrayList.wrap(new int[] { 1, 2 } ));
+		assertEquals(IntArrayList.wrap(new int[] { 0, 1, 2, 3 }), l);
+		// Test object based lists still work too.
+		l.addAll(2, java.util.Arrays.asList(Integer.valueOf(4), Integer.valueOf(5)));
+		assertEquals(IntArrayList.wrap(new int[] { 0, 1, 4, 5, 2, 3 }), l);
+	}
+
 	@Test
 	public void testRemoveAll() {
 		IntArrayList l = IntArrayList.wrap(new int[] { 0, 1, 1, 2 });
@@ -63,7 +83,7 @@ public class IntArrayListTest {
 
 	@Test
 	public void testSort() {
-		IntArrayList l = IntArrayList.wrap(new int[] { 4, 2, 1, 3 });
+		final IntArrayList l = IntArrayList.wrap(new int[] { 4, 2, 1, 3 });
 		l.sort(null);
 		assertEquals(IntArrayList.wrap(new int[] { 1, 2, 3, 4 }), l);
 	}
@@ -128,4 +148,9 @@ public class IntArrayListTest {
 		l.size(100);
 	}
 
+	@Test
+	public void testOf() {
+		final IntArrayList l = IntArrayList.of(0, 1, 2);
+		assertEquals(IntArrayList.wrap(new int[] { 0, 1, 2 }), l);
+	}
 }
