@@ -16,9 +16,9 @@ package it.unimi.dsi.fastutil.ints;
  * limitations under the License.
  */
 
-import it.unimi.dsi.fastutil.ints.IntArraySet;
-import it.unimi.dsi.fastutil.ints.IntOpenHashSet;
-import it.unimi.dsi.fastutil.io.BinIO;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -26,13 +26,21 @@ import java.io.IOException;
 import java.io.ObjectOutputStream;
 import java.util.Arrays;
 import java.util.Collections;
+import java.util.HashSet;
 
 import org.junit.Test;
 
-import static org.junit.Assert.*;
+import it.unimi.dsi.fastutil.io.BinIO;
 
 public class IntArraySetTest {
 
+	@Test
+	public void testCopyConstructor() {
+		final IntOpenHashSet s = new IntOpenHashSet(new int[] { 1, 2 });
+		assertEquals(new IntArraySet(s), s);
+		assertEquals(new HashSet<>(s), s);
+	}
+
 	@SuppressWarnings("boxing")
 	@Test
 	public void testNullInEquals() {
@@ -70,7 +78,7 @@ public class IntArraySetTest {
 
 	@Test
 	public void testClone() {
-		IntArraySet s = new IntArraySet();
+		final IntArraySet s = new IntArraySet();
 		assertEquals(s, s.clone());
 		s.add(0);
 		assertEquals(s, s.clone());
@@ -86,8 +94,8 @@ public class IntArraySetTest {
 
 	@Test
 	public void testSerialisation() throws IOException, ClassNotFoundException {
-		IntArraySet s = new IntArraySet();
-		ByteArrayOutputStream baos = new ByteArrayOutputStream();
+		final IntArraySet s = new IntArraySet();
+		final ByteArrayOutputStream baos = new ByteArrayOutputStream();
 		ObjectOutputStream oos = new ObjectOutputStream(baos);
 		oos.writeObject(s);
 		oos.close();
