@@ -237,7 +237,7 @@ public class IntOpenCustomHashSetTest {
 
 		/* Now we save and read m. */
 
-		java.io.File ff = new java.io.File("it.unimi.dsi.fastutil.test");
+		java.io.File ff = new java.io.File("it.unimi.dsi.fastutil.test.junit." + m.getClass().getSimpleName() + "." + n);
 		java.io.OutputStream os = new java.io.FileOutputStream(ff);
 		java.io.ObjectOutputStream oos = new java.io.ObjectOutputStream(os);
 
